<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Dejan Levec <webphp@gmail.com>
 * @author Boštjan Seničar <senicar@gmail.com>
 * @author Gregor Skumavc (grega.skumavc@gmail.com)
 * @author Matej Urbančič (mateju@svn.gnome.org)
 */
$lang['admin_acl']             = 'Upravljanje dostopa';
$lang['acl_group']             = 'Skupina:';
$lang['acl_user']              = 'Uporabnik:';
$lang['acl_perms']             = 'Dovoljenja za';
$lang['page']                  = 'Stran';
$lang['namespace']             = 'Imenski prostor';
$lang['btn_select']            = 'Izberi';
$lang['p_user_id']             = 'Uporabnik %s ima naslednja dovoljenja za stran %s: %s.';
$lang['p_user_ns']             = 'Uporabnik %s ima naslednja dovoljenja za imenski prostor %s: %s.';
$lang['p_group_id']            = 'Uporabniška skupina %s ima naslednja dovoljenja za stran %s: %s.';
$lang['p_group_ns']            = 'Uporabniška skupina %s ima naslednja dovoljenja za imenski prostor %s: %s.';
$lang['p_choose_id']           = 'Vnesite ime <b>uporabnika ali skupine</b> v zgornji obrazec za ogled ali urejanje dovoljenj za stran %s.';
$lang['p_choose_ns']           = 'Vnesite ime <b>uporabnika ali skupine</b> v zgornji obrazec za ogled ali urejanje dovoljenj za imenski prostor %s.';
$lang['p_inherited']           = 'Opomba: trenutna dovoljenja niso bila posebej določena, temveč so bila prevzeta iz drugih skupin ali višjih imenskih prostorov.';
$lang['p_isadmin']             = 'Opomba: izbrana skupina ali uporabnik imajo vsa dovoljenja za spreminjanje, saj so določeni kot skrbniki sistema.';
$lang['p_include']             = 'Višja dovoljenja vključujejo tudi nižja. ';
$lang['current']               = 'Trenutna pravila dostopa';
$lang['where']                 = 'Stran / Imenski prostor';
$lang['who']                   = 'Uporabnik/Skupina';
$lang['perm']                  = 'Dovoljenja';
$lang['acl_perm0']             = 'Nič';
$lang['acl_perm1']             = 'Preberi';
$lang['acl_perm2']             = 'Uredi';
$lang['acl_perm4']             = 'Ustvari';
$lang['acl_perm8']             = 'Naloži';
$lang['acl_perm16']            = 'Zbriši';
$lang['acl_new']               = 'Dodaj nov zapis';
$lang['acl_mod']               = 'Spremeni zapis';
